"""
Type annotations for iot-roborunner service client.

[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/client/)

Usage::

    ```python
    from boto3.session import Session
    from mypy_boto3_iot_roborunner.client import IoTRoboRunnerClient

    session = Session()
    client: IoTRoboRunnerClient = session.client("iot-roborunner")
    ```
"""
import sys
from typing import Any, Dict, Mapping, Type, overload

from botocore.client import BaseClient, ClientMeta

from .literals import DestinationStateType
from .paginator import (
    ListDestinationsPaginator,
    ListSitesPaginator,
    ListWorkerFleetsPaginator,
    ListWorkersPaginator,
)
from .type_defs import (
    CreateDestinationResponseTypeDef,
    CreateSiteResponseTypeDef,
    CreateWorkerFleetResponseTypeDef,
    CreateWorkerResponseTypeDef,
    GetDestinationResponseTypeDef,
    GetSiteResponseTypeDef,
    GetWorkerFleetResponseTypeDef,
    GetWorkerResponseTypeDef,
    ListDestinationsResponseTypeDef,
    ListSitesResponseTypeDef,
    ListWorkerFleetsResponseTypeDef,
    ListWorkersResponseTypeDef,
    OrientationTypeDef,
    PositionCoordinatesTypeDef,
    UpdateDestinationResponseTypeDef,
    UpdateSiteResponseTypeDef,
    UpdateWorkerFleetResponseTypeDef,
    UpdateWorkerResponseTypeDef,
    VendorPropertiesTypeDef,
)

if sys.version_info >= (3, 9):
    from typing import Literal
else:
    from typing_extensions import Literal


__all__ = ("IoTRoboRunnerClient",)


class BotocoreClientError(BaseException):
    MSG_TEMPLATE: str

    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
        self.response: Dict[str, Any]
        self.operation_name: str


class Exceptions:
    AccessDeniedException: Type[BotocoreClientError]
    ClientError: Type[BotocoreClientError]
    ConflictException: Type[BotocoreClientError]
    InternalServerException: Type[BotocoreClientError]
    ResourceNotFoundException: Type[BotocoreClientError]
    ServiceQuotaExceededException: Type[BotocoreClientError]
    ThrottlingException: Type[BotocoreClientError]
    ValidationException: Type[BotocoreClientError]


class IoTRoboRunnerClient(BaseClient):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Client)
    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/client/)
    """

    meta: ClientMeta

    @property
    def exceptions(self) -> Exceptions:
        """
        IoTRoboRunnerClient exceptions.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Client.exceptions)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/client/#exceptions)
        """

    def can_paginate(self, operation_name: str) -> bool:
        """
        Check if an operation can be paginated.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Client.can_paginate)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/client/#can_paginate)
        """

    def close(self) -> None:
        """
        Closes underlying endpoint connections.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Client.close)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/client/#close)
        """

    def create_destination(
        self,
        *,
        name: str,
        site: str,
        clientToken: str = ...,
        state: DestinationStateType = ...,
        additionalFixedProperties: str = ...
    ) -> CreateDestinationResponseTypeDef:
        """
        Grants permission to create a destination See also: [AWS API
        Documentation](https://docs.aws.amazon.com/goto/WebAPI/iot-
        roborunner-2018-05-10/CreateDestination).

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Client.create_destination)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/client/#create_destination)
        """

    def create_site(
        self, *, name: str, countryCode: str, clientToken: str = ..., description: str = ...
    ) -> CreateSiteResponseTypeDef:
        """
        Grants permission to create a site See also: [AWS API
        Documentation](https://docs.aws.amazon.com/goto/WebAPI/iot-
        roborunner-2018-05-10/CreateSite).

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Client.create_site)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/client/#create_site)
        """

    def create_worker(
        self,
        *,
        name: str,
        fleet: str,
        clientToken: str = ...,
        additionalTransientProperties: str = ...,
        additionalFixedProperties: str = ...,
        vendorProperties: VendorPropertiesTypeDef = ...,
        position: PositionCoordinatesTypeDef = ...,
        orientation: OrientationTypeDef = ...
    ) -> CreateWorkerResponseTypeDef:
        """
        Grants permission to create a worker See also: [AWS API
        Documentation](https://docs.aws.amazon.com/goto/WebAPI/iot-
        roborunner-2018-05-10/CreateWorker).

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Client.create_worker)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/client/#create_worker)
        """

    def create_worker_fleet(
        self, *, name: str, site: str, clientToken: str = ..., additionalFixedProperties: str = ...
    ) -> CreateWorkerFleetResponseTypeDef:
        """
        Grants permission to create a worker fleet See also: [AWS API
        Documentation](https://docs.aws.amazon.com/goto/WebAPI/iot-
        roborunner-2018-05-10/CreateWorkerFleet).

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Client.create_worker_fleet)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/client/#create_worker_fleet)
        """

    def delete_destination(self, *, id: str) -> Dict[str, Any]:
        """
        Grants permission to delete a destination See also: [AWS API
        Documentation](https://docs.aws.amazon.com/goto/WebAPI/iot-
        roborunner-2018-05-10/DeleteDestination).

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Client.delete_destination)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/client/#delete_destination)
        """

    def delete_site(self, *, id: str) -> Dict[str, Any]:
        """
        Grants permission to delete a site See also: [AWS API
        Documentation](https://docs.aws.amazon.com/goto/WebAPI/iot-
        roborunner-2018-05-10/DeleteSite).

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Client.delete_site)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/client/#delete_site)
        """

    def delete_worker(self, *, id: str) -> Dict[str, Any]:
        """
        Grants permission to delete a worker See also: [AWS API
        Documentation](https://docs.aws.amazon.com/goto/WebAPI/iot-
        roborunner-2018-05-10/DeleteWorker).

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Client.delete_worker)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/client/#delete_worker)
        """

    def delete_worker_fleet(self, *, id: str) -> Dict[str, Any]:
        """
        Grants permission to delete a worker fleet See also: [AWS API
        Documentation](https://docs.aws.amazon.com/goto/WebAPI/iot-
        roborunner-2018-05-10/DeleteWorkerFleet).

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Client.delete_worker_fleet)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/client/#delete_worker_fleet)
        """

    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Mapping[str, Any] = ...,
        ExpiresIn: int = 3600,
        HttpMethod: str = ...,
    ) -> str:
        """
        Generate a presigned url given a client, its method, and arguments.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Client.generate_presigned_url)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/client/#generate_presigned_url)
        """

    def get_destination(self, *, id: str) -> GetDestinationResponseTypeDef:
        """
        Grants permission to get a destination See also: [AWS API
        Documentation](https://docs.aws.amazon.com/goto/WebAPI/iot-
        roborunner-2018-05-10/GetDestination).

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Client.get_destination)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/client/#get_destination)
        """

    def get_site(self, *, id: str) -> GetSiteResponseTypeDef:
        """
        Grants permission to get a site See also: [AWS API
        Documentation](https://docs.aws.amazon.com/goto/WebAPI/iot-
        roborunner-2018-05-10/GetSite).

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Client.get_site)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/client/#get_site)
        """

    def get_worker(self, *, id: str) -> GetWorkerResponseTypeDef:
        """
        Grants permission to get a worker See also: [AWS API
        Documentation](https://docs.aws.amazon.com/goto/WebAPI/iot-
        roborunner-2018-05-10/GetWorker).

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Client.get_worker)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/client/#get_worker)
        """

    def get_worker_fleet(self, *, id: str) -> GetWorkerFleetResponseTypeDef:
        """
        Grants permission to get a worker fleet See also: [AWS API
        Documentation](https://docs.aws.amazon.com/goto/WebAPI/iot-
        roborunner-2018-05-10/GetWorkerFleet).

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Client.get_worker_fleet)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/client/#get_worker_fleet)
        """

    def list_destinations(
        self,
        *,
        site: str,
        maxResults: int = ...,
        nextToken: str = ...,
        state: DestinationStateType = ...
    ) -> ListDestinationsResponseTypeDef:
        """
        Grants permission to list destinations See also: [AWS API
        Documentation](https://docs.aws.amazon.com/goto/WebAPI/iot-
        roborunner-2018-05-10/ListDestinations).

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Client.list_destinations)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/client/#list_destinations)
        """

    def list_sites(
        self, *, maxResults: int = ..., nextToken: str = ...
    ) -> ListSitesResponseTypeDef:
        """
        Grants permission to list sites See also: [AWS API
        Documentation](https://docs.aws.amazon.com/goto/WebAPI/iot-
        roborunner-2018-05-10/ListSites).

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Client.list_sites)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/client/#list_sites)
        """

    def list_worker_fleets(
        self, *, site: str, maxResults: int = ..., nextToken: str = ...
    ) -> ListWorkerFleetsResponseTypeDef:
        """
        Grants permission to list worker fleets See also: [AWS API
        Documentation](https://docs.aws.amazon.com/goto/WebAPI/iot-
        roborunner-2018-05-10/ListWorkerFleets).

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Client.list_worker_fleets)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/client/#list_worker_fleets)
        """

    def list_workers(
        self, *, site: str, maxResults: int = ..., nextToken: str = ..., fleet: str = ...
    ) -> ListWorkersResponseTypeDef:
        """
        Grants permission to list workers See also: [AWS API
        Documentation](https://docs.aws.amazon.com/goto/WebAPI/iot-
        roborunner-2018-05-10/ListWorkers).

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Client.list_workers)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/client/#list_workers)
        """

    def update_destination(
        self,
        *,
        id: str,
        name: str = ...,
        state: DestinationStateType = ...,
        additionalFixedProperties: str = ...
    ) -> UpdateDestinationResponseTypeDef:
        """
        Grants permission to update a destination See also: [AWS API
        Documentation](https://docs.aws.amazon.com/goto/WebAPI/iot-
        roborunner-2018-05-10/UpdateDestination).

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Client.update_destination)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/client/#update_destination)
        """

    def update_site(
        self, *, id: str, name: str = ..., countryCode: str = ..., description: str = ...
    ) -> UpdateSiteResponseTypeDef:
        """
        Grants permission to update a site See also: [AWS API
        Documentation](https://docs.aws.amazon.com/goto/WebAPI/iot-
        roborunner-2018-05-10/UpdateSite).

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Client.update_site)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/client/#update_site)
        """

    def update_worker(
        self,
        *,
        id: str,
        name: str = ...,
        additionalTransientProperties: str = ...,
        additionalFixedProperties: str = ...,
        vendorProperties: VendorPropertiesTypeDef = ...,
        position: PositionCoordinatesTypeDef = ...,
        orientation: OrientationTypeDef = ...
    ) -> UpdateWorkerResponseTypeDef:
        """
        Grants permission to update a worker See also: [AWS API
        Documentation](https://docs.aws.amazon.com/goto/WebAPI/iot-
        roborunner-2018-05-10/UpdateWorker).

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Client.update_worker)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/client/#update_worker)
        """

    def update_worker_fleet(
        self, *, id: str, name: str = ..., additionalFixedProperties: str = ...
    ) -> UpdateWorkerFleetResponseTypeDef:
        """
        Grants permission to update a worker fleet See also: [AWS API
        Documentation](https://docs.aws.amazon.com/goto/WebAPI/iot-
        roborunner-2018-05-10/UpdateWorkerFleet).

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Client.update_worker_fleet)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/client/#update_worker_fleet)
        """

    @overload
    def get_paginator(
        self, operation_name: Literal["list_destinations"]
    ) -> ListDestinationsPaginator:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Client.get_paginator)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/client/#get_paginator)
        """

    @overload
    def get_paginator(self, operation_name: Literal["list_sites"]) -> ListSitesPaginator:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Client.get_paginator)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/client/#get_paginator)
        """

    @overload
    def get_paginator(
        self, operation_name: Literal["list_worker_fleets"]
    ) -> ListWorkerFleetsPaginator:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Client.get_paginator)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/client/#get_paginator)
        """

    @overload
    def get_paginator(self, operation_name: Literal["list_workers"]) -> ListWorkersPaginator:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Client.get_paginator)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/client/#get_paginator)
        """



"""
Main interface for iot-roborunner service.

Usage::

    ```python
    from boto3.session import Session
    from mypy_boto3_iot_roborunner import (
        Client,
        IoTRoboRunnerClient,
        ListDestinationsPaginator,
        ListSitesPaginator,
        ListWorkerFleetsPaginator,
        ListWorkersPaginator,
    )

    session = Session()
    client: IoTRoboRunnerClient = session.client("iot-roborunner")

    list_destinations_paginator: ListDestinationsPaginator = client.get_paginator("list_destinations")
    list_sites_paginator: ListSitesPaginator = client.get_paginator("list_sites")
    list_worker_fleets_paginator: ListWorkerFleetsPaginator = client.get_paginator("list_worker_fleets")
    list_workers_paginator: ListWorkersPaginator = client.get_paginator("list_workers")
    ```
"""
from .client import IoTRoboRunnerClient
from .paginator import (
    ListDestinationsPaginator,
    ListSitesPaginator,
    ListWorkerFleetsPaginator,
    ListWorkersPaginator,
)

Client = IoTRoboRunnerClient


__all__ = (
    "Client",
    "IoTRoboRunnerClient",
    "ListDestinationsPaginator",
    "ListSitesPaginator",
    "ListWorkerFleetsPaginator",
    "ListWorkersPaginator",
)



"""
Type annotations for iot-roborunner service client paginators.

[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from mypy_boto3_iot_roborunner.client import IoTRoboRunnerClient
    from mypy_boto3_iot_roborunner.paginator import (
        ListDestinationsPaginator,
        ListSitesPaginator,
        ListWorkerFleetsPaginator,
        ListWorkersPaginator,
    )

    session = Session()
    client: IoTRoboRunnerClient = session.client("iot-roborunner")

    list_destinations_paginator: ListDestinationsPaginator = client.get_paginator("list_destinations")
    list_sites_paginator: ListSitesPaginator = client.get_paginator("list_sites")
    list_worker_fleets_paginator: ListWorkerFleetsPaginator = client.get_paginator("list_worker_fleets")
    list_workers_paginator: ListWorkersPaginator = client.get_paginator("list_workers")
    ```
"""
from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .literals import DestinationStateType
from .type_defs import (
    ListDestinationsResponseTypeDef,
    ListSitesResponseTypeDef,
    ListWorkerFleetsResponseTypeDef,
    ListWorkersResponseTypeDef,
    PaginatorConfigTypeDef,
)

__all__ = (
    "ListDestinationsPaginator",
    "ListSitesPaginator",
    "ListWorkerFleetsPaginator",
    "ListWorkersPaginator",
)


_ItemTypeDef = TypeVar("_ItemTypeDef")


class _PageIterator(Generic[_ItemTypeDef], PageIterator):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """


class ListDestinationsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Paginator.ListDestinations)
    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/paginators/#listdestinationspaginator)
    """

    def paginate(
        self,
        *,
        site: str,
        state: DestinationStateType = ...,
        PaginationConfig: PaginatorConfigTypeDef = ...
    ) -> _PageIterator[ListDestinationsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Paginator.ListDestinations.paginate)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/paginators/#listdestinationspaginator)
        """


class ListSitesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Paginator.ListSites)
    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/paginators/#listsitespaginator)
    """

    def paginate(
        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
    ) -> _PageIterator[ListSitesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Paginator.ListSites.paginate)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/paginators/#listsitespaginator)
        """


class ListWorkerFleetsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Paginator.ListWorkerFleets)
    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/paginators/#listworkerfleetspaginator)
    """

    def paginate(
        self, *, site: str, PaginationConfig: PaginatorConfigTypeDef = ...
    ) -> _PageIterator[ListWorkerFleetsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Paginator.ListWorkerFleets.paginate)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/paginators/#listworkerfleetspaginator)
        """


class ListWorkersPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Paginator.ListWorkers)
    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/paginators/#listworkerspaginator)
    """

    def paginate(
        self, *, site: str, fleet: str = ..., PaginationConfig: PaginatorConfigTypeDef = ...
    ) -> _PageIterator[ListWorkersResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-roborunner.html#IoTRoboRunner.Paginator.ListWorkers.paginate)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/paginators/#listworkerspaginator)
        """



"""
Type annotations for iot-roborunner service type definitions.

[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_roborunner/type_defs/)

Usage::

    ```python
    from mypy_boto3_iot_roborunner.type_defs import CartesianCoordinatesTypeDef

    data: CartesianCoordinatesTypeDef = {...}
    ```
"""
import sys
from datetime import datetime
from typing import Dict, List

from .literals import DestinationStateType

if sys.version_info >= (3, 9):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict

__all__ = (
    "CartesianCoordinatesTypeDef",
    "CreateDestinationRequestRequestTypeDef",
    "ResponseMetadataTypeDef",
    "CreateSiteRequestRequestTypeDef",
    "CreateWorkerFleetRequestRequestTypeDef",
    "OrientationTypeDef",
    "VendorPropertiesTypeDef",
    "DeleteDestinationRequestRequestTypeDef",
    "DeleteSiteRequestRequestTypeDef",
    "DeleteWorkerFleetRequestRequestTypeDef",
    "DeleteWorkerRequestRequestTypeDef",
    "DestinationTypeDef",
    "GetDestinationRequestRequestTypeDef",
    "GetSiteRequestRequestTypeDef",
    "GetWorkerFleetRequestRequestTypeDef",
    "GetWorkerRequestRequestTypeDef",
    "PaginatorConfigTypeDef",
    "ListDestinationsRequestRequestTypeDef",
    "ListSitesRequestRequestTypeDef",
    "SiteTypeDef",
    "ListWorkerFleetsRequestRequestTypeDef",
    "WorkerFleetTypeDef",
    "ListWorkersRequestRequestTypeDef",
    "UpdateDestinationRequestRequestTypeDef",
    "UpdateSiteRequestRequestTypeDef",
    "UpdateWorkerFleetRequestRequestTypeDef",
    "PositionCoordinatesTypeDef",
    "CreateDestinationResponseTypeDef",
    "CreateSiteResponseTypeDef",
    "CreateWorkerFleetResponseTypeDef",
    "CreateWorkerResponseTypeDef",
    "GetDestinationResponseTypeDef",
    "GetSiteResponseTypeDef",
    "GetWorkerFleetResponseTypeDef",
    "UpdateDestinationResponseTypeDef",
    "UpdateSiteResponseTypeDef",
    "UpdateWorkerFleetResponseTypeDef",
    "ListDestinationsResponseTypeDef",
    "ListDestinationsRequestListDestinationsPaginateTypeDef",
    "ListSitesRequestListSitesPaginateTypeDef",
    "ListWorkerFleetsRequestListWorkerFleetsPaginateTypeDef",
    "ListWorkersRequestListWorkersPaginateTypeDef",
    "ListSitesResponseTypeDef",
    "ListWorkerFleetsResponseTypeDef",
    "CreateWorkerRequestRequestTypeDef",
    "GetWorkerResponseTypeDef",
    "UpdateWorkerRequestRequestTypeDef",
    "UpdateWorkerResponseTypeDef",
    "WorkerTypeDef",
    "ListWorkersResponseTypeDef",
)

_RequiredCartesianCoordinatesTypeDef = TypedDict(
    "_RequiredCartesianCoordinatesTypeDef",
    {
        "x": float,
        "y": float,
    },
)
_OptionalCartesianCoordinatesTypeDef = TypedDict(
    "_OptionalCartesianCoordinatesTypeDef",
    {
        "z": float,
    },
    total=False,
)

class CartesianCoordinatesTypeDef(
    _RequiredCartesianCoordinatesTypeDef, _OptionalCartesianCoordinatesTypeDef
):
    pass

_RequiredCreateDestinationRequestRequestTypeDef = TypedDict(
    "_RequiredCreateDestinationRequestRequestTypeDef",
    {
        "name": str,
        "site": str,
    },
)
_OptionalCreateDestinationRequestRequestTypeDef = TypedDict(
    "_OptionalCreateDestinationRequestRequestTypeDef",
    {
        "clientToken": str,
        "state": DestinationStateType,
        "additionalFixedProperties": str,
    },
    total=False,
)

class CreateDestinationRequestRequestTypeDef(
    _RequiredCreateDestinationRequestRequestTypeDef, _OptionalCreateDestinationRequestRequestTypeDef
):
    pass

ResponseMetadataTypeDef = TypedDict(
    "ResponseMetadataTypeDef",
    {
        "RequestId": str,
        "HostId": str,
        "HTTPStatusCode": int,
        "HTTPHeaders": Dict[str, str],
        "RetryAttempts": int,
    },
)

_RequiredCreateSiteRequestRequestTypeDef = TypedDict(
    "_RequiredCreateSiteRequestRequestTypeDef",
    {
        "name": str,
        "countryCode": str,
    },
)
_OptionalCreateSiteRequestRequestTypeDef = TypedDict(
    "_OptionalCreateSiteRequestRequestTypeDef",
    {
        "clientToken": str,
        "description": str,
    },
    total=False,
)

class CreateSiteRequestRequestTypeDef(
    _RequiredCreateSiteRequestRequestTypeDef, _OptionalCreateSiteRequestRequestTypeDef
):
    pass

_RequiredCreateWorkerFleetRequestRequestTypeDef = TypedDict(
    "_RequiredCreateWorkerFleetRequestRequestTypeDef",
    {
        "name": str,
        "site": str,
    },
)
_OptionalCreateWorkerFleetRequestRequestTypeDef = TypedDict(
    "_OptionalCreateWorkerFleetRequestRequestTypeDef",
    {
        "clientToken": str,
        "additionalFixedProperties": str,
    },
    total=False,
)

class CreateWorkerFleetRequestRequestTypeDef(
    _RequiredCreateWorkerFleetRequestRequestTypeDef, _OptionalCreateWorkerFleetRequestRequestTypeDef
):
    pass

OrientationTypeDef = TypedDict(
    "OrientationTypeDef",
    {
        "degrees": float,
    },
    total=False,
)

_RequiredVendorPropertiesTypeDef = TypedDict(
    "_RequiredVendorPropertiesTypeDef",
    {
        "vendorWorkerId": str,
    },
)
_OptionalVendorPropertiesTypeDef = TypedDict(
    "_OptionalVendorPropertiesTypeDef",
    {
        "vendorWorkerIpAddress": str,
        "vendorAdditionalTransientProperties": str,
        "vendorAdditionalFixedProperties": str,
    },
    total=False,
)

class VendorPropertiesTypeDef(_RequiredVendorPropertiesTypeDef, _OptionalVendorPropertiesTypeDef):
    pass

DeleteDestinationRequestRequestTypeDef = TypedDict(
    "DeleteDestinationRequestRequestTypeDef",
    {
        "id": str,
    },
)

DeleteSiteRequestRequestTypeDef = TypedDict(
    "DeleteSiteRequestRequestTypeDef",
    {
        "id": str,
    },
)

DeleteWorkerFleetRequestRequestTypeDef = TypedDict(
    "DeleteWorkerFleetRequestRequestTypeDef",
    {
        "id": str,
    },
)

DeleteWorkerRequestRequestTypeDef = TypedDict(
    "DeleteWorkerRequestRequestTypeDef",
    {
        "id": str,
    },
)

_RequiredDestinationTypeDef = TypedDict(
    "_RequiredDestinationTypeDef",
    {
        "arn": str,
        "id": str,
        "name": str,
        "site": str,
        "createdAt": datetime,
        "updatedAt": datetime,
        "state": DestinationStateType,
    },
)
_OptionalDestinationTypeDef = TypedDict(
    "_OptionalDestinationTypeDef",
    {
        "additionalFixedProperties": str,
    },
    total=False,
)

class DestinationTypeDef(_RequiredDestinationTypeDef, _OptionalDestinationTypeDef):
    pass

GetDestinationRequestRequestTypeDef = TypedDict(
    "GetDestinationRequestRequestTypeDef",
    {
        "id": str,
    },
)

GetSiteRequestRequestTypeDef = TypedDict(
    "GetSiteRequestRequestTypeDef",
    {
        "id": str,
    },
)

GetWorkerFleetRequestRequestTypeDef = TypedDict(
    "GetWorkerFleetRequestRequestTypeDef",
    {
        "id": str,
    },
)

GetWorkerRequestRequestTypeDef = TypedDict(
    "GetWorkerRequestRequestTypeDef",
    {
        "id": str,
    },
)

PaginatorConfigTypeDef = TypedDict(
    "PaginatorConfigTypeDef",
    {
        "MaxItems": int,
        "PageSize": int,
        "StartingToken": str,
    },
    total=False,
)

_RequiredListDestinationsRequestRequestTypeDef = TypedDict(
    "_RequiredListDestinationsRequestRequestTypeDef",
    {
        "site": str,
    },
)
_OptionalListDestinationsRequestRequestTypeDef = TypedDict(
    "_OptionalListDestinationsRequestRequestTypeDef",
    {
        "maxResults": int,
        "nextToken": str,
        "state": DestinationStateType,
    },
    total=False,
)

class ListDestinationsRequestRequestTypeDef(
    _RequiredListDestinationsRequestRequestTypeDef, _OptionalListDestinationsRequestRequestTypeDef
):
    pass

ListSitesRequestRequestTypeDef = TypedDict(
    "ListSitesRequestRequestTypeDef",
    {
        "maxResults": int,
        "nextToken": str,
    },
    total=False,
)

SiteTypeDef = TypedDict(
    "SiteTypeDef",
    {
        "arn": str,
        "name": str,
        "countryCode": str,
        "createdAt": datetime,
    },
)

_RequiredListWorkerFleetsRequestRequestTypeDef = TypedDict(
    "_RequiredListWorkerFleetsRequestRequestTypeDef",
    {
        "site": str,
    },
)
_OptionalListWorkerFleetsRequestRequestTypeDef = TypedDict(
    "_OptionalListWorkerFleetsRequestRequestTypeDef",
    {
        "maxResults": int,
        "nextToken": str,
    },
    total=False,
)

class ListWorkerFleetsRequestRequestTypeDef(
    _RequiredListWorkerFleetsRequestRequestTypeDef, _OptionalListWorkerFleetsRequestRequestTypeDef
):
    pass

_RequiredWorkerFleetTypeDef = TypedDict(
    "_RequiredWorkerFleetTypeDef",
    {
        "arn": str,
        "id": str,
        "name": str,
        "site": str,
        "createdAt": datetime,
        "updatedAt": datetime,
    },
)
_OptionalWorkerFleetTypeDef = TypedDict(
    "_OptionalWorkerFleetTypeDef",
    {
        "additionalFixedProperties": str,
    },
    total=False,
)

class WorkerFleetTypeDef(_RequiredWorkerFleetTypeDef, _OptionalWorkerFleetTypeDef):
    pass

_RequiredListWorkersRequestRequestTypeDef = TypedDict(
    "_RequiredListWorkersRequestRequestTypeDef",
    {
        "site": str,
    },
)
_OptionalListWorkersRequestRequestTypeDef = TypedDict(
    "_OptionalListWorkersRequestRequestTypeDef",
    {
        "maxResults": int,
        "nextToken": str,
        "fleet": str,
    },
    total=False,
)

class ListWorkersRequestRequestTypeDef(
    _RequiredListWorkersRequestRequestTypeDef, _OptionalListWorkersRequestRequestTypeDef
):
    pass

_RequiredUpdateDestinationRequestRequestTypeDef = TypedDict(
    "_RequiredUpdateDestinationRequestRequestTypeDef",
    {
        "id": str,
    },
)
_OptionalUpdateDestinationRequestRequestTypeDef = TypedDict(
    "_OptionalUpdateDestinationRequestRequestTypeDef",
    {
        "name": str,
        "state": DestinationStateType,
        "additionalFixedProperties": str,
    },
    total=False,
)

class UpdateDestinationRequestRequestTypeDef(
    _RequiredUpdateDestinationRequestRequestTypeDef, _OptionalUpdateDestinationRequestRequestTypeDef
):
    pass

_RequiredUpdateSiteRequestRequestTypeDef = TypedDict(
    "_RequiredUpdateSiteRequestRequestTypeDef",
    {
        "id": str,
    },
)
_OptionalUpdateSiteRequestRequestTypeDef = TypedDict(
    "_OptionalUpdateSiteRequestRequestTypeDef",
    {
        "name": str,
        "countryCode": str,
        "description": str,
    },
    total=False,
)

class UpdateSiteRequestRequestTypeDef(
    _RequiredUpdateSiteRequestRequestTypeDef, _OptionalUpdateSiteRequestRequestTypeDef
):
    pass

_RequiredUpdateWorkerFleetRequestRequestTypeDef = TypedDict(
    "_RequiredUpdateWorkerFleetRequestRequestTypeDef",
    {
        "id": str,
    },
)
_OptionalUpdateWorkerFleetRequestRequestTypeDef = TypedDict(
    "_OptionalUpdateWorkerFleetRequestRequestTypeDef",
    {
        "name": str,
        "additionalFixedProperties": str,
    },
    total=False,
)

class UpdateWorkerFleetRequestRequestTypeDef(
    _RequiredUpdateWorkerFleetRequestRequestTypeDef, _OptionalUpdateWorkerFleetRequestRequestTypeDef
):
    pass

PositionCoordinatesTypeDef = TypedDict(
    "PositionCoordinatesTypeDef",
    {
        "cartesianCoordinates": CartesianCoordinatesTypeDef,
    },
    total=False,
)

CreateDestinationResponseTypeDef = TypedDict(
    "CreateDestinationResponseTypeDef",
    {
        "arn": str,
        "id": str,
        "createdAt": datetime,
        "updatedAt": datetime,
        "state": DestinationStateType,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

CreateSiteResponseTypeDef = TypedDict(
    "CreateSiteResponseTypeDef",
    {
        "arn": str,
        "id": str,
        "createdAt": datetime,
        "updatedAt": datetime,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

CreateWorkerFleetResponseTypeDef = TypedDict(
    "CreateWorkerFleetResponseTypeDef",
    {
        "arn": str,
        "id": str,
        "createdAt": datetime,
        "updatedAt": datetime,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

CreateWorkerResponseTypeDef = TypedDict(
    "CreateWorkerResponseTypeDef",
    {
        "arn": str,
        "id": str,
        "createdAt": datetime,
        "updatedAt": datetime,
        "site": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

GetDestinationResponseTypeDef = TypedDict(
    "GetDestinationResponseTypeDef",
    {
        "arn": str,
        "id": str,
        "name": str,
        "site": str,
        "createdAt": datetime,
        "updatedAt": datetime,
        "state": DestinationStateType,
        "additionalFixedProperties": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

GetSiteResponseTypeDef = TypedDict(
    "GetSiteResponseTypeDef",
    {
        "arn": str,
        "id": str,
        "name": str,
        "countryCode": str,
        "description": str,
        "createdAt": datetime,
        "updatedAt": datetime,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

GetWorkerFleetResponseTypeDef = TypedDict(
    "GetWorkerFleetResponseTypeDef",
    {
        "id": str,
        "arn": str,
        "name": str,
        "site": str,
        "createdAt": datetime,
        "updatedAt": datetime,
        "additionalFixedProperties": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

UpdateDestinationResponseTypeDef = TypedDict(
    "UpdateDestinationResponseTypeDef",
    {
        "arn": str,
        "id": str,
        "name": str,
        "updatedAt": datetime,
        "state": DestinationStateType,
        "additionalFixedProperties": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

UpdateSiteResponseTypeDef = TypedDict(
    "UpdateSiteResponseTypeDef",
    {
        "arn": str,
        "id": str,
        "name": str,
        "countryCode": str,
        "description": str,
        "updatedAt": datetime,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

UpdateWorkerFleetResponseTypeDef = TypedDict(
    "UpdateWorkerFleetResponseTypeDef",
    {
        "arn": str,
        "id": str,
        "name": str,
        "updatedAt": datetime,
        "additionalFixedProperties": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

ListDestinationsResponseTypeDef = TypedDict(
    "ListDestinationsResponseTypeDef",
    {
        "nextToken": str,
        "destinations": List[DestinationTypeDef],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

_RequiredListDestinationsRequestListDestinationsPaginateTypeDef = TypedDict(
    "_RequiredListDestinationsRequestListDestinationsPaginateTypeDef",
    {
        "site": str,
    },
)
_OptionalListDestinationsRequestListDestinationsPaginateTypeDef = TypedDict(
    "_OptionalListDestinationsRequestListDestinationsPaginateTypeDef",
    {
        "state": DestinationStateType,
        "PaginationConfig": PaginatorConfigTypeDef,
    },
    total=False,
)

class ListDestinationsRequestListDestinationsPaginateTypeDef(
    _RequiredListDestinationsRequestListDestinationsPaginateTypeDef,
    _OptionalListDestinationsRequestListDestinationsPaginateTypeDef,
):
    pass

ListSitesRequestListSitesPaginateTypeDef = TypedDict(
    "ListSitesRequestListSitesPaginateTypeDef",
    {
        "PaginationConfig": PaginatorConfigTypeDef,
    },
    total=False,
)

_RequiredListWorkerFleetsRequestListWorkerFleetsPaginateTypeDef = TypedDict(
    "_RequiredListWorkerFleetsRequestListWorkerFleetsPaginateTypeDef",
    {
        "site": str,
    },
)
_OptionalListWorkerFleetsRequestListWorkerFleetsPaginateTypeDef = TypedDict(
    "_OptionalListWorkerFleetsRequestListWorkerFleetsPaginateTypeDef",
    {
        "PaginationConfig": PaginatorConfigTypeDef,
    },
    total=False,
)

class ListWorkerFleetsRequestListWorkerFleetsPaginateTypeDef(
    _RequiredListWorkerFleetsRequestListWorkerFleetsPaginateTypeDef,
    _OptionalListWorkerFleetsRequestListWorkerFleetsPaginateTypeDef,
):
    pass

_RequiredListWorkersRequestListWorkersPaginateTypeDef = TypedDict(
    "_RequiredListWorkersRequestListWorkersPaginateTypeDef",
    {
        "site": str,
    },
)
_OptionalListWorkersRequestListWorkersPaginateTypeDef = TypedDict(
    "_OptionalListWorkersRequestListWorkersPaginateTypeDef",
    {
        "fleet": str,
        "PaginationConfig": PaginatorConfigTypeDef,
    },
    total=False,
)

class ListWorkersRequestListWorkersPaginateTypeDef(
    _RequiredListWorkersRequestListWorkersPaginateTypeDef,
    _OptionalListWorkersRequestListWorkersPaginateTypeDef,
):
    pass

ListSitesResponseTypeDef = TypedDict(
    "ListSitesResponseTypeDef",
    {
        "nextToken": str,
        "sites": List[SiteTypeDef],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

ListWorkerFleetsResponseTypeDef = TypedDict(
    "ListWorkerFleetsResponseTypeDef",
    {
        "nextToken": str,
        "workerFleets": List[WorkerFleetTypeDef],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

_RequiredCreateWorkerRequestRequestTypeDef = TypedDict(
    "_RequiredCreateWorkerRequestRequestTypeDef",
    {
        "name": str,
        "fleet": str,
    },
)
_OptionalCreateWorkerRequestRequestTypeDef = TypedDict(
    "_OptionalCreateWorkerRequestRequestTypeDef",
    {
        "clientToken": str,
        "additionalTransientProperties": str,
        "additionalFixedProperties": str,
        "vendorProperties": VendorPropertiesTypeDef,
        "position": PositionCoordinatesTypeDef,
        "orientation": OrientationTypeDef,
    },
    total=False,
)

class CreateWorkerRequestRequestTypeDef(
    _RequiredCreateWorkerRequestRequestTypeDef, _OptionalCreateWorkerRequestRequestTypeDef
):
    pass

GetWorkerResponseTypeDef = TypedDict(
    "GetWorkerResponseTypeDef",
    {
        "arn": str,
        "id": str,
        "fleet": str,
        "site": str,
        "createdAt": datetime,
        "updatedAt": datetime,
        "name": str,
        "additionalTransientProperties": str,
        "additionalFixedProperties": str,
        "vendorProperties": VendorPropertiesTypeDef,
        "position": PositionCoordinatesTypeDef,
        "orientation": OrientationTypeDef,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

_RequiredUpdateWorkerRequestRequestTypeDef = TypedDict(
    "_RequiredUpdateWorkerRequestRequestTypeDef",
    {
        "id": str,
    },
)
_OptionalUpdateWorkerRequestRequestTypeDef = TypedDict(
    "_OptionalUpdateWorkerRequestRequestTypeDef",
    {
        "name": str,
        "additionalTransientProperties": str,
        "additionalFixedProperties": str,
        "vendorProperties": VendorPropertiesTypeDef,
        "position": PositionCoordinatesTypeDef,
        "orientation": OrientationTypeDef,
    },
    total=False,
)

class UpdateWorkerRequestRequestTypeDef(
    _RequiredUpdateWorkerRequestRequestTypeDef, _OptionalUpdateWorkerRequestRequestTypeDef
):
    pass

UpdateWorkerResponseTypeDef = TypedDict(
    "UpdateWorkerResponseTypeDef",
    {
        "arn": str,
        "id": str,
        "fleet": str,
        "updatedAt": datetime,
        "name": str,
        "additionalTransientProperties": str,
        "additionalFixedProperties": str,
        "orientation": OrientationTypeDef,
        "vendorProperties": VendorPropertiesTypeDef,
        "position": PositionCoordinatesTypeDef,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

_RequiredWorkerTypeDef = TypedDict(
    "_RequiredWorkerTypeDef",
    {
        "arn": str,
        "id": str,
        "fleet": str,
        "createdAt": datetime,
        "updatedAt": datetime,
        "name": str,
        "site": str,
    },
)
_OptionalWorkerTypeDef = TypedDict(
    "_OptionalWorkerTypeDef",
    {
        "additionalTransientProperties": str,
        "additionalFixedProperties": str,
        "vendorProperties": VendorPropertiesTypeDef,
        "position": PositionCoordinatesTypeDef,
        "orientation": OrientationTypeDef,
    },
    total=False,
)

class WorkerTypeDef(_RequiredWorkerTypeDef, _OptionalWorkerTypeDef):
    pass

ListWorkersResponseTypeDef = TypedDict(
    "ListWorkersResponseTypeDef",
    {
        "nextToken": str,
        "workers": List[WorkerTypeDef],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
